def cube():
    n=int(input("Enter the Number!!!!!\n"))
    print("The square of {} is {}".format(n,n**3))
